# Table of Contents

- [single-sign-on-sso](<./single-sign-on-sso.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Single Sign-On (SSO)](<./Single-Sign-On-SSO.md>)
  - [Overview](<./Single-Sign-On-SSO/Overview.md>)
  - [Authentication Flow](<./Single-Sign-On-SSO/Authentication-Flow.md>)
  - [Requirements for Identity Providers](<./Single-Sign-On-SSO/Requirements-for-Identity-Providers.md>)
  - [Example Identity Providers](<./Single-Sign-On-SSO/Example-Identity-Providers.md>)
  - [Configuring SSO](<./Single-Sign-On-SSO/Configuring-SSO.md>)
  - [Managing User Roles with SSO](<./Single-Sign-On-SSO/Managing-User-Roles-with-SSO.md>)
  - [Managing User Roles Within SAP LeanIX](<./Single-Sign-On-SSO/Managing-User-Roles-Within-SAP-LeanIX.md>)
  - [Managing User Roles Within the Identity Provider](<./Single-Sign-On-SSO/Managing-User-Roles-Within-the-Identity-Provider.md>)
  - [Attribute Mapping](<./Single-Sign-On-SSO/Attribute-Mapping.md>)
  - [Example SAML Message with User Attributes](<./Single-Sign-On-SSO/Example-SAML-Message-with-User-Attributes.md>)
  - [Custom User Roles](<./Single-Sign-On-SSO/Custom-User-Roles.md>)
  - [Transient Users with SSO](<./Single-Sign-On-SSO/Transient-Users-with-SSO.md>)
  - [Troubleshooting](<./Single-Sign-On-SSO/Troubleshooting.md>)
  - [Was this page helpful?](<./Single-Sign-On-SSO/Was-this-page-helpful.md>)
